TO use this project,  you have to import pdf2text module:
```from sohampdf import pdf2text```
Then there is only one method currently in our project. And that prints the text `pdf2text`. To use it, type:
```pdf2text.convert()```